@@ -27,11 +27,6 @@ set_include_path(implode(PATH_SEPARATOR, [
 $vendorAutoload = $basePath . '/vendor/autoload.php';
 if (file_exists($vendorAutoload)) {
     require_once $vendorAutoload;
-} else {
-    require_once 'Mockery/Loader.php';
-
-    $mockeryLoader = new \Mockery\Loader;
-    $mockeryLoader->register();
 }
 
 require_once($icingaLibPath . '/Test/ClassLoader.php');
@@ -41,6 +36,34 @@ $loader->registerNamespace('Tests', $testLibraryPath);
 $loader->registerNamespace('Icinga', $icingaLibPath);
 $loader->registerNamespace('Icinga\\Forms', $applicationPath . '/forms');
 
+$libraryPaths = getenv('ICINGAWEB_LIBDIR');
+if ($libraryPaths !== false) {
+    $libraryPaths = array_filter(array_map(
+        'realpath',
+        explode(':', $libraryPaths)
+    ), 'is_dir');
+} else {
+    $libraryPaths = is_dir('/usr/share/icinga-php')
+        ? ['/usr/share/icinga-php']
+        : [];
+}
+
+foreach ($libraryPaths as $externalLibraryPath) {
+    $libPaths = array_flip(scandir($externalLibraryPath));
+    unset($libPaths['.']);
+    unset($libPaths['..']);
+    $libPaths = array_keys($libPaths);
+    foreach ($libPaths as $libPath) {
+        $libPath = join(DIRECTORY_SEPARATOR, [$externalLibraryPath, $libPath]);
+        if (is_dir(realpath($libPath))) {
+            $libAutoLoader = join(DIRECTORY_SEPARATOR, [$libPath, 'vendor', 'autoload.php']);
+            if (file_exists($libAutoLoader)) {
+                require_once $libAutoLoader;
+            }
+        }
+    }
+}
+
 $modulePaths = getenv('ICINGAWEB_MODULE_DIRS');
 
 if ($modulePaths) {
@@ -89,6 +112,13 @@ set_include_path(
     )
 );
 
+if (! class_exists('Mockery')) {
+    require_once 'Mockery/Loader.php';
+
+    $mockeryLoader = new \Mockery\Loader;
+    $mockeryLoader->register();
+}
+
 require_once 'Zend/Loader/Autoloader.php';
 \Zend_Loader_Autoloader::getInstance();
 
